@@ -1,28 +1,35 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
 """
 Data Loader main entry point
 """
 
 
-from future import standard_library
-
-standard_library.install_aliases()
-from builtins import object
+import configparser
 import os.path as op
 import queue
-import configparser
-
 
 import splunktalib.concurrent.concurrent_executor as ce
-import splunktalib.timer_queue as tq
 import splunktalib.schedule.job as sjob
+import splunktalib.timer_queue as tq
 from splunktalib.common import log
 
 
-class TADataLoader(object):
+class TADataLoader:
     """
     Data Loader boots all underlying facilities to handle data collection
     """
@@ -141,8 +148,8 @@ class TADataLoader(object):
         return settings
 
 
-class GlobalDataLoader(object):
-    """ Singleton, inited when started"""
+class GlobalDataLoader:
+    """Singleton, inited when started"""
 
     __instance = None
 
